
# **FROM FLOWERS TO EARTH** 

## **ABSTRACT** 

![PROCESS](../images/process/Untitled-1%20copy2.jpg){ width=1000 }

My final project titled "From Flowers to Earth," addresses the environmental challenges posed by flower waste in both the floral industry and the funeral industry. By transforming discarded roses and natural fibers into biodegradable burial garments, the project bridges the gap between the short-timed beauty of flowers and sustainable afterlife practices. Through meticulous research and experimentation with natural dyes and biofabrication techniques, it highlights the potential of circular economy principles in the floral industry, contributing to both environmental sustainability and cultural practices surrounding death.


## **BACKGROUND** 

![PROCESS](../images/process/P20.jpg){ width=1000 }

My hometown Kunming, known as the "City of Eternal Spring," hosts Asia's largest flower market. Despite the market's vibrancy, approximately 40% of flower production is wasted due to the short lifespan of cut flowers. This project draws attention to the environmental impact of this waste and proposes a new solution by repurposing flowers for biodegradable products. 

![PROCESS](../images/process/Untitled-1%20copy3.jpg){ width=1000 }

The practice of using flowers in funerals is common, yet often leads to additional waste when the flowers are discarded after ceremonies. Recognizing the composting potential of flowers, I aim to explore their transformation into sustainable burial garments.

The central concept of this project is to utilize floral waste to create biodegradable burial garments that enrich the soil. This approach not only reduces landfill waste but also integrates the beauty and symbolism of flowers into sustainable death care practices. When the flowers decompose, they return to the earth accompanying the deceased person and gift their essence to the soil, becoming nourishments for future blooms. 


## **A HISTORICAL JOURNEY TO MODERN PRACTICES** 

The history of burial garments spans across cultures and time, reflecting different traditions and beliefs about death and the afterlife. In ancient Egypt, mummification involved wrapping the deceased in linen shrouds, signifying status and preparing them for the journey to the afterlife. In medieval Europe, shrouds and simple white linens were customary, symbolizing purity and the soul’s journey.

By the 19th century, especially during the Victorian era, burial garments became more elaborate, often mirroring the fashion of the time. These garments were specifically designed for the deceased, incorporating elements like lace and fine fabrics, and were often chosen to reflect the individual's social status and identity.

In modern times, the practice of dressing the deceased in their own garments has become very common, expressing personal identity and preferences. This shift is partly due to the move towards more personalized and meaningful funeral services. Families often choose garments that hold sentimental value, such as a favorite dress or suit which reminds them the personality of the deceased. This modern practice underscores a desire for authenticity and a connection to the life and individuality of the loved one, marking a significant evolution from traditional burial garments to contemporary, personalized choices.

![PROCESS](../images/process/P22.jpg){ width=1000 }

Although being buried in one's own clothes provides a personal and sentimental touch to funerals, it raises significant environmental concerns due to the common use of synthetic fibers in modern clothing. Synthetic fibers such as polyester, nylon, and acrylic are widely used in contemporary apparel for their durability, affordability, and versatility. However, these materials pose several problems when used as burial garments.

Firstly, synthetic fibers are not biodegradable. Unlike natural fibers like cotton, wool, or linen, synthetic materials do not easily break down in the soil, leading to prolonged environmental impact. These fibers can take hundreds of years to decompose, contributing to landfill accumulation and soil pollution.

Secondly, the decomposition of synthetic fibers can release harmful chemicals and microplastics into the environment. As these materials slowly degrade, they can leach toxic substances, such as dyes and finishing agents, into the soil and groundwater, potentially contaminating surrounding ecosystems.Furthurmore, they are often treated with various chemicals during manufacturing to enhance properties like stain resistance and water repellency. These chemicals can pose further environmental hazards when released during decomposition.

## **SUSTAINABLE BURIAL SOLUTIONS**

It is necessary to carefully consider the environmental impact of synthetic fibers. Promoting the use of biodegradable, natural fibers in burial practices can mitigate these adverse effects and contribute to more sustainable funeral traditions. 

[Koloběh Manufaktura](https://kolobehmanufaktura.cz/) is an environmental manufactory that focuses on creating eco-friendly products with a deep connection to sustainability and traditional craftsmanship. They offer a range of burial shrouds and cloths, crafted from natural fibers that decompose easily. These garments are intended to return to the earth seamlessly, supporting natural cycles of decomposition and nutrient recycling.

![PROCESS](../images/process/P23.jpg){ width=1000 }

Pia Interlandi is an Australian fashion designer known for her innovative work in creating biodegradable burial garments. Her approach integrates design, science, and ritual to offer a meaningful and environmentally conscious alternative to traditional burial practices. She focuses on simplicity and ease of use, making it easier to dress the deceased. The garments often have features like wraparound closures and soft fabrics that respect the dignity of the deceased and provide comfort to those handling them.

## **METHODOLOGY**

![PROCESS](../images/process/P21.jpg){ width=1000 }

The project employs a multi-faceted approach, combining natural dyeing of natural fibers and biofabricated textiles. Roses, chosen for their popularity in funerals and dyeing properties, were used to create natural dyes for various fibers and creating bio-materials using sodium alginate.

## **SOIL CHROMATOGRAPHY**

To prove the positive impact of flowers on soil health, I performed a test known as soil chromatography. Soil chromatography is an analytical technique used to separate and identify the different components in a soil sample. It is based on the principle that different substances will move at different rates when dissolved in a solvent and passed through a medium. 

![PROCESS](../images/process/P4.jpg){ width=1000 }

Soil chromatography can provide visual indicators of soil health by revealing the distribution and concentration of organic and inorganic substances within the soil. The graphs above demonstrate how rose petals and rose leaves nourish the soil in various ways: 

1. Diverse and Well-Distributed Bands: The presence of multiple distinct bands can suggest a balanced and nutrient-rich soil.

2. Rich Organic Matter: The presence of dark, well-defined bands near the center can indicate a high content of organic matter. 

3. Color Intensity: Rich, intense colors in the bands can indicate the presence of various nutrients and a high level of biological activity.


## **BIO CHROMES**

![PROCESS](../images/process/Untitled-1%20copy5.jpg){ width=1000 }

The experimentation process began with creating natural dyes from rose petals and leaves, comparing their colours and effectiveness on different fibers,including wool, cotton, linen, bamboo, and silk. The fabrics were mordanted with alum resulted in a diverse color palette and ensured color fastness. Wool and silk displayed the best results, absorbing the dye more effectively than other fibers.

## **BIO FABRICATION**

In the mean time, bio-material experiments involved embedding rose petals and leaves in agar agar and alginate, leading to the discovery of optimal polymer for durable and visually appealing textiles. Inspired by Damien Hirst's vibrant paintings, these experiments sought to replicate similar textures using roses. Initially, agar agar was used for its biodegradability and gel-like consistency, but I realized that alginate, a polymer derived from brown algae, provided a more suitable medium for creating flat, thin textiles ideal for burial garments.


![PROCESS](../images/process/Untitled-1%20copy6.jpg){ width=1000 }

To preserve the fresh colors of the rose petals and prevent decay, I scattered the petals on top of the alginate layer.  This method not only creates a velvety texture but also ensured that the petals did not come into direct contact with water, maintaining their vibrant hues for a longer period.  In contrast, the leaves were soaked in the alginate, as their combination with the petals contributed more nutrients to the soil upon decomposition.


![PROCESS](../images/process/Untitled-1%20copy7.jpg){ width=1000 }

The resulting textiles not only captured the visual essence inspired by Hirst's paintings but also offered an environmentally friendly solution for burial garments. The use of alginate ensured that the textiles were flat and manageable, while the careful placement of petals and leaves provided both aesthetic appeal and ecological benefits, enriching the soil as they decomposed.

## **DESIGN**

![PROCESS](../images/process/P2.jpg){ width=1000 }

Inspired by historical burial garments and contemporary fashion design, the project culminated in a burial gown for women, incorporating elements from early 20th-century English shrouds and Balenciaga wedding dresses. The gown design emphasized simplicity, elegance, and ease of dressing the deceased. 

## **FABRICATION**

### **PROCESS VIDEO** 

My approach is both circular and zero-waste, ensuring every part of the rose is utilized effectively. You can follow the steps in the video below:

<div style="padding:56.25% 0 0 0;position:relative;"><iframe src="https://player.vimeo.com/video/954286609?badge=0&amp;autopause=0&amp;player_id=0&amp;app_id=58479" frameborder="0" allow="autoplay; fullscreen; picture-in-picture; clipboard-write" style="position:absolute;top:0;left:0;width:100%;height:100%;" title="FROM FLOWERS TO EARTH"></iframe></div><script src="https://player.vimeo.com/api/player.js"></script>

First, I carefully sorted the rose petals and leaves, dehydrating them to prevent rot and extend their usability. Then, I created a dye bath using the rose leaves, which I used to dye natural fibers, maximizing the utility of the plant materials. The leftover dye water was repurposed to cast alginate onto wool, integrating sustainability into the textile creation process. Finally, I scattered the rose petals on top of the alginate to create a velvety fabric, which I used to craft burial garments. This method not only produces beautiful, biodegradable textiles but also minimizes waste.

![PROCESS](../images/process/Untitled-1%20copy9.jpg){ width=1000 }

Using a heating blanket, the alginate textile cured within four days. Once cured, the fabric can be handled like any conventional material; it can be cut with standard scissors and sewn with a sewing machine.

![PROCESS](../images/process/Untitled-1%20copy10.jpg){ width=1000 }

## **FUTURE WORK**

Future research could expand the range of flowers and natural fibers used, explore alternative bio-polymers or other bio-mateirals such as mycelium, and develop scalable production methods. Additionally, collaboration with local communities and industries could enhance the project's impact, fostering a broader shift towards sustainable practices in the floral and textile industry.

## **REFERENCES**


